@@ -3,4 +3,4 @@ from django.apps import AppConfig
 
 class CbvHtmxConfig(AppConfig):
     default_auto_field = "django.db.models.BigAutoField"
-    name = "django-cbv-htmx.cbvhtmx"
+    name = "cbvhtmx"
